<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://realestatecrm.io
 * @since      1.0.0
 *
 * @package    Cf7_recrmio
 * @subpackage Cf7_recrmio/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Cf7_recrmio
 * @subpackage Cf7_recrmio/includes
 * @author     Your Name <email@realestatecrm.io>
 */
class Cf7_recrmio
{

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Cf7_recrmio_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $cf7_recrmio    The string used to uniquely identify this plugin.
	 */
	protected $cf7_recrmio;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;


	
	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct()
	{
		if (defined('CF7_RECRMIO_VERSION')) {
			$this->version = CF7_RECRMIO_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->cf7_recrmio = 'cf7-recrmio';

		$this->register_options();
		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Cf7_recrmio_Loader. Orchestrates the hooks of the plugin.
	 * - Cf7_recrmio_i18n. Defines internationalization functionality.
	 * - Cf7_recrmio_Admin. Defines all hooks for the admin area.
	 * - Cf7_recrmio_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies()
	{

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-cf7-recrmio-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-cf7-recrmio-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-cf7-recrmio-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-cf7-recrmio-public.php';

		$this->loader = new Cf7_recrmio_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Cf7_recrmio_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale()
	{

		$plugin_i18n = new Cf7_recrmio_i18n();

		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks()
	{

		$plugin_admin = new Cf7_recrmio_Admin($this->get_cf7_recrmio(), $this->get_version());
		$this->loader->add_action('admin_notices',  $this, 'verify_dependencies');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
		// add menu hook 
		$this->loader->add_action('admin_menu', $plugin_admin, 'register_setting_menu', 11);
		// add menu hook 
		$this->loader->add_action('admin_menu', $plugin_admin, 'register_log_menu', 11);

		// add tab contact form 7

		/* adds another tab to contact form 7 screen */
		$this->loader->add_filter("wpcf7_editor_panels",$plugin_admin,'add_cf7_recrmio_tab', 12);
		/* actions to handle while saving the form */
		$this->loader->add_action( "wpcf7_save_contact_form",$plugin_admin , 'cf7_recrmio_save_contact_form_details', 10 , 1);
	}


	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks()
	{

		$plugin_public = new Cf7_recrmio_Public($this->get_cf7_recrmio(), $this->get_version());

		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
		$this->loader->add_action('wpcf7_mail_sent', $plugin_public, 'createDataFromWbForm');
		$this->loader->add_action('wpcf7_mail_failed', $plugin_public, 'createDataFromWbForm');
		
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run()
	{
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_cf7_recrmio()
	{
		return $this->cf7_recrmio;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Cf7_recrmio_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader()
	{
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version()
	{
		return $this->version;
	}



	/**
	 * Check if contact form 7 is active
	 * @return [type] [description]
	 */
	public function verify_dependencies()
	{
		if (!is_plugin_active('contact-form-7/wp-contact-form-7.php')) {
			$class = 'notice notice-error';
			$message = __('Contact form 7 + Realestatecrm requires CONTACT FORM 7 Plugin to be installed and active.', 'sample-text-domain');
			printf('<div class="%1$s"><p>%2$s</p></div>', esc_attr($class), esc_html($message));
			// update_option('cf7-recrmio_is_valid_key_log','Not found Contact form 7');
			// update_option('cf7-recrmio_is_valid_key', 'no');
			// update_option('cf7-recrmio_api_key', '');
			// update_option('cf7-recrmio_company_id', '');
		}
	}

	public function register_options()
	{
		register_setting('cf7-recrmio', 'cf7-recrmio_api_key');
		register_setting('cf7-recrmio', 'cf7-recrmio_company_name');
		register_setting('cf7-recrmio', 'cf7-recrmio_is_valid_key');
		register_setting('cf7-recrmio', 'cf7-recrmio_is_valid_key_log');
	}
}
